--- check_mrtgtraf.c	2003-11-12 06:41:28.000000000 +0100
+++ ../../nagios-plugins-1.4.0alpha1.new/plugins/check_mrtgtraf.c	2004-02-23 17:56:06.008358000 +0100
@@ -32,6 +32,7 @@
 char *log_file = NULL;
 int expire_minutes = -1;
 int use_average = TRUE;
+int use_bits = FALSE;
 unsigned long incoming_warning_threshold = 0L;
 unsigned long incoming_critical_threshold = 0L;
 unsigned long outgoing_warning_threshold = 0L;
@@ -47,6 +48,7 @@
 	int result = STATE_OK;
 	FILE *fp;
 	int line;
+	char threshold_factor = 1;
 	char input_buffer[MAX_INPUT_BUFFER];
 	char *temp_buffer;
 	time_t current_time;
@@ -130,48 +132,54 @@
 		outgoing_rate = maximum_outgoing_rate;
 	}
 
-	/* report incoming traffic in Bytes/sec */
+	if (use_bits) {
+		incoming_rate *= 8;
+		outgoing_rate *= 8;
+		threshold_factor = 8;
+	}
+
+	/* report incoming traffic in Bytes/sec or bit/sec */
 	if (incoming_rate < 1024) {
-		strcpy (incoming_speed_rating, "B/s");
+		strcpy (incoming_speed_rating, (use_bits ? "bit/s" : "B/s"));
 		adjusted_incoming_rate = (double) incoming_rate;
 	}
 
-	/* report incoming traffic in KBytes/sec */
+	/* report incoming traffic in KBytes/sec or Kbit/sec*/
 	else if (incoming_rate < (1024 * 1024)) {
-		strcpy (incoming_speed_rating, "KB/s");
+		strcpy (incoming_speed_rating, (use_bits ? "Kbit/s" : "KB/s"));
 		adjusted_incoming_rate = (double) (incoming_rate / 1024.0);
 	}
 
-	/* report incoming traffic in MBytes/sec */
+	/* report incoming traffic in MBytes/sec or Mbit/sec */
 	else {
-		strcpy (incoming_speed_rating, "MB/s");
+		strcpy (incoming_speed_rating, (use_bits ? "Mbit/s" : "MB/s"));
 		adjusted_incoming_rate = (double) (incoming_rate / 1024.0 / 1024.0);
 	}
 
-	/* report outgoing traffic in Bytes/sec */
+	/* report outgoing traffic in Bytes/sec or bit/sec */
 	if (outgoing_rate < 1024) {
-		strcpy (outgoing_speed_rating, "B/s");
+		strcpy (outgoing_speed_rating, (use_bits ? "bit/s" : "B/s"));
 		adjusted_outgoing_rate = (double) outgoing_rate;
 	}
 
-	/* report outgoing traffic in KBytes/sec */
+	/* report outgoing traffic in KBytes/sec or Kbit/sec */
 	else if (outgoing_rate < (1024 * 1024)) {
-		strcpy (outgoing_speed_rating, "KB/s");
+		strcpy (outgoing_speed_rating, (use_bits ? "Kbit/s" : "KB/s"));
 		adjusted_outgoing_rate = (double) (outgoing_rate / 1024.0);
 	}
 
-	/* report outgoing traffic in MBytes/sec */
+	/* report outgoing traffic in MBytes/sec or Mbit/sec */
 	else {
-		strcpy (outgoing_speed_rating, "MB/s");
+		strcpy (outgoing_speed_rating, (use_bits ? "Mbit/s" : "MB/s"));
 		adjusted_outgoing_rate = (double) (outgoing_rate / 1024.0 / 1024.0);
 	}
 
-	if (incoming_rate > incoming_critical_threshold
-			|| outgoing_rate > outgoing_critical_threshold) {
+	if (incoming_rate > (incoming_critical_threshold * threshold_factor)
+			|| outgoing_rate > (outgoing_critical_threshold * threshold_factor)) {
 		result = STATE_CRITICAL;
 	}
-	else if (incoming_rate > incoming_warning_threshold
-					 || outgoing_rate > outgoing_warning_threshold) {
+	else if (incoming_rate > (incoming_warning_threshold * threshold_factor)
+					 || outgoing_rate > (outgoing_warning_threshold * threshold_factor)) {
 		result = STATE_WARNING;
 	}
 
@@ -180,10 +188,10 @@
 	          incoming_speed_rating, (use_average == TRUE) ? _("Avg") : _("Max"),
 	          adjusted_outgoing_rate, outgoing_speed_rating,
 	          perfdata("in", (long) adjusted_incoming_rate, incoming_speed_rating,
-	                   (int) incoming_warning_threshold, (long) incoming_warning_threshold,
+	                   (int) incoming_warning_threshold , (long) incoming_warning_threshold,
 	                   (int) incoming_critical_threshold, (long) incoming_critical_threshold,
 	                   TRUE, 0, TRUE, (long) incoming_speed_rating),
-	          perfdata("in", (long) adjusted_outgoing_rate, outgoing_speed_rating,
+	          perfdata("out", (long) adjusted_outgoing_rate, outgoing_speed_rating,
 	                   (int) outgoing_warning_threshold, (long) outgoing_warning_threshold,
 	                   (int) outgoing_critical_threshold, (long) outgoing_critical_threshold,
 	                   TRUE, 0, TRUE, (long) outgoing_speed_rating));
@@ -204,6 +212,7 @@
 		{"logfile", required_argument, 0, 'F'},
 		{"expires", required_argument, 0, 'e'},
 		{"aggregation", required_argument, 0, 'a'},
+		{"bits", required_argument, 0, 'b'},
 		{"variable", required_argument, 0, 'v'},
 		{"critical", required_argument, 0, 'c'},
 		{"warning", required_argument, 0, 'w'},
@@ -226,7 +235,7 @@
 	}
 
 	while (1) {
-		c = getopt_long (argc, argv, "hVF:e:a:c:w:", longopts, &option);
+		c = getopt_long (argc, argv, "hVF:e:a:bc:w:", longopts, &option);
 
 		if (c == -1 || c == EOF)
 			break;
@@ -244,6 +253,10 @@
 			else
 				use_average = TRUE;
 			break;
+		case 'b':
+		/* aggregation values bit/s-based */
+			use_bits = TRUE;
+			break;
 		case 'c':									/* warning threshold */
 			sscanf (optarg, "%lu,%lu", &incoming_critical_threshold,
 							&outgoing_critical_threshold);
@@ -334,6 +347,7 @@
    Minutes after which log expires\n\
  -a, --aggregation=(AVG|MAX)\n\
    Test average or maximum\n\
+ -b  Report bit/s instead of byte/s\n\
  -w, --warning\n\
    Warning threshold pair \"<incoming>,<outgoing>\"\n\
  -c, --critical\n\
@@ -344,7 +358,8 @@
 switch, etc recorded in an MRTG log.  If the newest log entry is older\n\
 than <expire_minutes>, a WARNING status is returned. If either the\n\
 incoming or outgoing rates exceed the <icl> or <ocl> thresholds (in\n\
-Bytes/sec), a CRITICAL status results.  If either of the rates exceed\n\
+Bytes/sec or bits/sec depending on using -b), a CRITICAL status results.\n\
+If either of the rates exceed\n\
 the <iwl> or <owl> thresholds (in Bytes/sec), a WARNING status results.\n\n"));
 
 	printf (_("Notes:\n\
@@ -366,7 +381,7 @@
 print_usage (void)
 {
 	printf (_("\
-Usage: %s -F <log_file> -a <AVG | MAX> -v <variable> -w <warning_pair> -c <critical_pair>\n\
+Usage: %s -F <log_file> -a <AVG | MAX> -b -v <variable> -w <warning_pair> -c <critical_pair>\n\
   [-e expire_minutes] [-t timeout] [-v]\n"), progname);
 	printf (_(UT_HLP_VRS), progname, progname);
 }
